@@ -128,6 +128,10 @@ class OptionsManager(object):
 
         return path
 
+    def save_to_default(self) -> str:
+        """保存当前配置到默认ini文件"""
+        return self.save('default')
+
 
 class SessionOptions(object):
     def __init__(self, read_file: bool = True, ini_path: str = None):
@@ -410,8 +414,13 @@ class SessionOptions(object):
         """
         if path == 'default':
             path = (Path(__file__).parent / 'configs.ini').absolute()
+
         elif path is None:
-            path = Path(self.ini_path).absolute()
+            if self.ini_path:
+                path = Path(self.ini_path).absolute()
+            else:
+                path = (Path(__file__).parent / 'configs.ini').absolute()
+
         else:
             path = Path(path).absolute()
 
@@ -432,6 +441,10 @@ class SessionOptions(object):
 
         return path
 
+    def save_to_default(self) -> str:
+        """保存当前配置到默认ini文件"""
+        return self.save('default')
+
     def as_dict(self) -> dict:
         """以字典形式返回本对象"""
         return _session_options_to_dict(self)
@@ -449,9 +462,10 @@ class DriverOptions(Options):
         """
         super().__init__()
         self._driver_path = None
-        self.ini_path = ini_path or str(Path(__file__).parent / 'configs.ini')
+        self.ini_path = None
 
         if read_file:
+            self.ini_path = ini_path or str(Path(__file__).parent / 'configs.ini')
             om = OptionsManager(self.ini_path)
             options_dict = om.chrome_options
 
@@ -471,21 +485,28 @@ class DriverOptions(Options):
 
     @property
     def driver_path(self) -> str:
+        """chromedriver文件路径"""
         return self._driver_path
 
     @property
     def chrome_path(self) -> str:
+        """浏览器启动文件路径"""
         return self.binary_location
 
     def save(self, path: str = None) -> str:
-        """保存设置到文件                                              \n
-        :param path: ini文件的路径，传入 'default' 保存到默认ini文件
+        """保存设置到文件                                                                        \n
+        :param path: ini文件的路径， None 保存到当前读取的配置文件，传入 'default' 保存到默认ini文件
         :return: 保存文件的绝对路径
         """
         if path == 'default':
             path = (Path(__file__).parent / 'configs.ini').absolute()
+
         elif path is None:
-            path = Path(self.ini_path).absolute()
+            if self.ini_path:
+                path = Path(self.ini_path).absolute()
+            else:
+                path = (Path(__file__).parent / 'configs.ini').absolute()
+
         else:
             path = Path(path).absolute()
 
@@ -509,6 +530,10 @@ class DriverOptions(Options):
 
         return path
 
+    def save_to_default(self) -> str:
+        """保存当前配置到默认ini文件"""
+        return self.save('default')
+
     def remove_argument(self, value: str) -> 'DriverOptions':
         """移除一个argument项                                    \n
         :param value: 设置项名，有值的设置项传入设置名称即可
@@ -658,7 +683,7 @@ class DriverOptions(Options):
             self.binary_location = chrome_path
 
         if local_port is not None:
-            self.debugger_address = f'127.0.0.1:{local_port}'
+            self.debugger_address = '' if local_port == '' else f'127.0.0.1:{local_port}'
 
         if debugger_address is not None:
             self.debugger_address = debugger_address
@@ -675,6 +700,7 @@ class DriverOptions(Options):
         return self
 
     def as_dict(self) -> dict:
+        """已dict方式返回所有配置信息"""
         return _chrome_options_to_dict(self)
 
 
@@ -702,6 +728,7 @@ def _chrome_options_to_dict(options: Union[dict, DriverOptions, Options, None, b
 
     if 'timeouts' in options_dir and 'timeouts' in options._caps:
         timeouts = options.__getattribute__('timeouts')
+        timeouts['implicit'] /= 1000
         timeouts['pageLoad'] /= 1000
         timeouts['script'] /= 1000
         re_dict['timeouts'] = timeouts
