@@ -18,8 +18,8 @@ from selenium.webdriver.support.wait import WebDriverWait
 
 from .base import BasePage
 from .common import get_usable_path
-from .driver_element import DriverElement, make_driver_ele, _wait_ele
-from .session_element import make_session_ele
+from .driver_element import DriverElement, make_driver_ele, Scroll, ElementWaiter
+from .session_element import make_session_ele, SessionElement
 
 
 class DriverPage(BasePage):
@@ -30,9 +30,10 @@ class DriverPage(BasePage):
         super().__init__(timeout)
         self._driver = driver
         self._wait_object = None
+        self._scroll = None
 
     def __call__(self, loc_or_str: Union[Tuple[str, str], str, DriverElement, WebElement],
-                 timeout: float = None) -> Union[DriverElement, List[DriverElement], str]:
+                 timeout: float = None) -> Union[DriverElement, str, None]:
         """在内部查找元素                                           \n
         例：ele = page('@id=ele_id')                              \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
@@ -63,24 +64,22 @@ class DriverPage(BasePage):
 
     def get(self,
             url: str,
-            go_anyway: bool = False,
             show_errmsg: bool = False,
             retry: int = None,
             interval: float = None) -> Union[None, bool]:
         """访问url                                            \n
         :param url: 目标url
-        :param go_anyway: 若目标url与当前url一致，是否强制跳转
         :param show_errmsg: 是否显示和抛出异常
         :param retry: 重试次数
         :param interval: 重试间隔（秒）
-        :return: 目标url是否可用
+        :return: 目标url是否可用，返回None表示不确定
         """
         to_url = quote(url, safe='/:&?=%;#@+!')
-        retry = int(retry) if retry is not None else int(self.retry_times)
-        interval = int(interval) if interval is not None else int(self.retry_interval)
+        retry = retry if retry is not None else self.retry_times
+        interval = interval if interval is not None else self.retry_interval
 
-        if not url or (not go_anyway and self.url == to_url):
-            return
+        if not url:
+            raise ValueError('没有传入url。')
 
         self._url = to_url
         self._url_available = self._try_to_connect(to_url, times=retry, interval=interval, show_errmsg=show_errmsg)
@@ -94,7 +93,7 @@ class DriverPage(BasePage):
 
     def ele(self,
             loc_or_ele: Union[Tuple[str, str], str, DriverElement, WebElement],
-            timeout: float = None) -> Union[DriverElement, List[DriverElement], str, None]:
+            timeout: float = None) -> Union[DriverElement, str, None]:
         """返回页面中符合条件的第一个元素                                          \n
         :param loc_or_ele: 元素的定位信息，可以是元素对象，loc元组，或查询字符串
         :param timeout: 查找元素超时时间，默认与页面等待时间一致
@@ -104,7 +103,7 @@ class DriverPage(BasePage):
 
     def eles(self,
              loc_or_str: Union[Tuple[str, str], str],
-             timeout: float = None) -> List[DriverElement]:
+             timeout: float = None) -> List[Union[DriverElement, str]]:
         """返回页面中所有符合条件的元素                                     \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :param timeout: 查找元素超时时间，默认与页面等待时间一致
@@ -112,7 +111,7 @@ class DriverPage(BasePage):
         """
         return self._ele(loc_or_str, timeout, single=False)
 
-    def s_ele(self, loc_or_ele: Union[Tuple[str, str], str, DriverElement] = None):
+    def s_ele(self, loc_or_ele: Union[Tuple[str, str], str, DriverElement] = None) -> Union[SessionElement, str, None]:
         """查找第一个符合条件的元素以SessionElement形式返回，处理复杂页面时效率很高       \n
         :param loc_or_ele: 元素的定位信息，可以是loc元组，或查询字符串
         :return: SessionElement对象或属性、文本
@@ -122,7 +121,7 @@ class DriverPage(BasePage):
         else:
             return make_session_ele(self, loc_or_ele)
 
-    def s_eles(self, loc_or_str: Union[Tuple[str, str], str] = None):
+    def s_eles(self, loc_or_str: Union[Tuple[str, str], str] = None) -> List[Union[SessionElement, str]]:
         """查找所有符合条件的元素以SessionElement列表形式返回                       \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :return: SessionElement对象组成的列表
@@ -132,7 +131,7 @@ class DriverPage(BasePage):
     def _ele(self,
              loc_or_ele: Union[Tuple[str, str], str, DriverElement, WebElement],
              timeout: float = None,
-             single: bool = True) -> Union[DriverElement, List[DriverElement], str, None]:
+             single: bool = True) -> Union[DriverElement, str, None, List[Union[DriverElement, str]]]:
         """返回页面中符合条件的元素，默认返回第一个                                   \n
         :param loc_or_ele: 元素的定位信息，可以是元素对象，loc元组，或查询字符串
         :param timeout: 查找元素超时时间
@@ -173,24 +172,17 @@ class DriverPage(BasePage):
         self._timeout = second
         self._wait_object = None
 
-    @property
-    def timeouts(self) -> dict:
-        """返回三种超时时间，selenium4以上版本可用"""
-        return {'implicit': self.timeout,
-                'pageLoad': self.driver.timeouts.page_load,
-                'script': self.driver.timeouts.script}
-
     def _try_to_connect(self,
                         to_url: str,
                         times: int = 0,
                         interval: float = 1,
-                        show_errmsg: bool = False):
+                        show_errmsg: bool = False) -> Union[bool, None]:
         """尝试连接，重试若干次                            \n
         :param to_url: 要访问的url
         :param times: 重试次数
         :param interval: 重试间隔（秒）
         :param show_errmsg: 是否抛出异常
-        :return: 是否成功
+        :return: 是否成功，返回None表示不确定
         """
         err = None
         is_ok = False
@@ -210,7 +202,8 @@ class DriverPage(BasePage):
 
             if _ < times:
                 sleep(interval)
-                print(f'重试 {to_url}')
+                if show_errmsg:
+                    print(f'重试 {to_url}')
 
         if is_ok is False and show_errmsg:
             raise err if err is not None else ConnectionError('连接异常。')
@@ -230,6 +223,13 @@ class DriverPage(BasePage):
 
         return self._wait_object
 
+    @property
+    def timeouts(self) -> dict:
+        """返回三种超时时间，selenium4以上版本可用"""
+        return {'implicit': self.timeout,
+                'pageLoad': self.driver.timeouts.page_load,
+                'script': self.driver.timeouts.script}
+
     @property
     def tabs_count(self) -> int:
         """返回标签页数量"""
@@ -258,6 +258,28 @@ class DriverPage(BasePage):
         """返回当前焦点所在元素"""
         return DriverElement(self.driver.switch_to.active_element, self)
 
+    @property
+    def scroll(self) -> Scroll:
+        """用于滚动滚动条的对象"""
+        if self._scroll is None:
+            self._scroll = Scroll(self)
+        return self._scroll
+
+    @property
+    def to_frame(self) -> 'ToFrame':
+        """用于跳转到frame的对象，调用其方法实现跳转                                             \n
+        示例：                                                                               \n
+            page.to_frame.by_loc('tag:iframe')               - 通过传入frame的查询字符串定位   \n
+            page.to_frame.by_loc((By.TAG_NAME, 'iframe'))    - 通过传入定位符定位             \n
+            page.to_frame.by_id('iframe_id')                 - 通过frame的id属性定位          \n
+            page.to_frame('iframe_name')                     - 通过frame的name属性定位        \n
+            page.to_frame(iframe_element)                    - 通过传入元素对象定位            \n
+            page.to_frame(0)                                 - 通过frame的序号定位            \n
+            page.to_frame.main()                             - 跳到最顶层                    \n
+            page.to_frame.parent()                           - 跳到上一层
+        """
+        return ToFrame(self)
+
     def set_timeouts(self, implicit: float = None, pageLoad: float = None, script: float = None) -> None:
         """设置超时时间，单位为秒，selenium4以上版本有效       \n
         :param implicit: 查找元素超时时间
@@ -276,15 +298,13 @@ class DriverPage(BasePage):
 
     def wait_ele(self,
                  loc_or_ele: Union[str, tuple, DriverElement, WebElement],
-                 mode: str,
-                 timeout: float = None) -> bool:
+                 timeout: float = None) -> 'ElementWaiter':
         """等待元素从dom删除、显示、隐藏                             \n
         :param loc_or_ele: 可以是元素、查询字符串、loc元组
-        :param mode: 等待方式，可选：'del', 'display', 'hidden'
         :param timeout: 等待超时时间
         :return: 等待是否成功
         """
-        return _wait_ele(self, loc_or_ele, mode, timeout)
+        return ElementWaiter(self, loc_or_ele, timeout)
 
     def check_page(self) -> Union[bool, None]:
         """检查页面是否符合预期            \n
@@ -308,6 +328,14 @@ class DriverPage(BasePage):
         """
         return self.driver.execute_async_script(script, *args)
 
+    def run_cdp(self, cmd: str, cmd_args: dict) -> Any:
+        """执行Chrome DevTools Protocol语句
+        :param cmd: 协议项目
+        :param cmd_args: 参数
+        :return: 执行的结果
+        """
+        return self.driver.execute_cdp_cmd(cmd, cmd_args)
+
     def create_tab(self, url: str = '') -> None:
         """新建并定位到一个标签页,该标签页在最后面       \n
         :param url: 新标签页跳转到的网址
@@ -325,7 +353,7 @@ class DriverPage(BasePage):
 
     def close_tabs(self, num_or_handles: Union[int, str, list, tuple] = None) -> None:
         """关闭传入的标签页，默认关闭当前页。可传入多个                                                     \n
-        注意：当程序使用的是截关的浏览器，获取到的 handle 顺序和视觉效果不一致，不能按序号关闭。
+        注意：当程序使用的是接管的浏览器，获取到的 handle 顺序和视觉效果不一致，不能按序号关闭。                 \n
         :param num_or_handles:要关闭的标签页序号或handle，可传入handle和序号组成的列表或元组，为None时关闭当前页
         :return: None
         """
@@ -338,12 +366,12 @@ class DriverPage(BasePage):
 
     def close_other_tabs(self, num_or_handles: Union[int, str, list, tuple] = None) -> None:
         """关闭传入的标签页以外标签页，默认保留当前页。可传入多个                                              \n
-        注意：当程序使用的是截关的浏览器，获取到的 handle 顺序和视觉效果不一致，不能按序号关闭。
+        注意：当程序使用的是接管的浏览器，获取到的 handle 顺序和视觉效果不一致，不能按序号关闭。                   \n
         :param num_or_handles: 要保留的标签页序号或handle，可传入handle和序号组成的列表或元组，为None时保存当前页
         :return: None
         """
         all_tabs = self.driver.window_handles
-        reserve_tabs = (self.current_tab_handle,) if num_or_handles is None else _get_handles(all_tabs, num_or_handles)
+        reserve_tabs = {self.current_tab_handle} if num_or_handles is None else _get_handles(all_tabs, num_or_handles)
 
         for i in set(all_tabs) - reserve_tabs:
             self.driver.switch_to.window(i)
@@ -353,6 +381,7 @@ class DriverPage(BasePage):
 
     def to_tab(self, num_or_handle: Union[int, str] = 0) -> None:
         """跳转到标签页                                                         \n
+        注意：当程序使用的是接管的浏览器，获取到的 handle 顺序和视觉效果不一致         \n
         :param num_or_handle: 标签页序号或handle字符串，序号第一个为0，最后为-1
         :return: None
         """
@@ -364,54 +393,12 @@ class DriverPage(BasePage):
         tab = self.driver.window_handles[tab] if isinstance(tab, int) else tab
         self.driver.switch_to.window(tab)
 
-    def to_frame(self, loc_or_ele: Union[int, str, tuple, WebElement, DriverElement] = 'main') -> 'DriverPage':
-        """跳转到frame                                                                       \n
-        可接收frame序号(0开始)、id或name、查询字符串、loc元组、WebElement对象、DriverElement对象，     \n
-        传入 'main' 跳到最高层，传入 'parent' 跳到上一层                                           \n
-        示例：                                                                                \n
-            to_frame('tag:iframe')    - 通过传入frame的查询字符串定位                             \n
-            to_frame('iframe_id')     - 通过frame的id属性定位                                   \n
-            to_frame('iframe_name')   - 通过frame的name属性定位                                 \n
-            to_frame(iframe_element)  - 通过传入元素对象定位                                     \n
-            to_frame(0)               - 通过frame的序号定位                                     \n
-            to_frame('main')          - 跳到最高层                                             \n
-            to_frame('parent')        - 跳到上一层                                             \n
-        :param loc_or_ele: iframe的定位信息
-        :return: 返回自己，用于链式操作
+    def set_ua_to_tab(self, ua: str) -> None:
+        """为当前tab设置user agent，只在当前tab有效          \n
+        :param ua: user agent字符串
+        :return: None
         """
-        # 根据序号跳转
-        if isinstance(loc_or_ele, int):
-            self.driver.switch_to.frame(loc_or_ele)
-
-        elif isinstance(loc_or_ele, str):
-            # 跳转到最上级
-            if loc_or_ele == 'main':
-                self.driver.switch_to.default_content()
-
-            # 跳转到上一层
-            elif loc_or_ele == 'parent':
-                self.driver.switch_to.parent_frame()
-
-            # 传入id或name
-            elif ':' not in loc_or_ele and '=' not in loc_or_ele and not loc_or_ele.startswith(('#', '.')):
-                self.driver.switch_to.frame(loc_or_ele)
-
-            # 传入控制字符串
-            else:
-                ele = self.ele(loc_or_ele)
-                self.driver.switch_to.frame(ele.inner_ele)
-
-        elif isinstance(loc_or_ele, WebElement):
-            self.driver.switch_to.frame(loc_or_ele)
-
-        elif isinstance(loc_or_ele, DriverElement):
-            self.driver.switch_to.frame(loc_or_ele.inner_ele)
-
-        elif isinstance(loc_or_ele, tuple):
-            ele = self.ele(loc_or_ele)
-            self.driver.switch_to.frame(ele.inner_ele)
-
-        return self
+        self.driver.execute_cdp_cmd("Network.setUserAgentOverride", {"userAgent": ua})
 
     def screenshot(self, path: str, filename: str = None) -> str:
         """截取页面可见范围截图                                  \n
@@ -436,47 +423,6 @@ class DriverPage(BasePage):
         ele = self.ele(loc_or_ele)
         ele.run_script("arguments[0].scrollIntoView();")
 
-    def scroll_to(self, mode: str = 'bottom', pixel: int = 300) -> None:
-        """按参数指示方式滚动页面                                                                                    \n
-        :param mode: 可选滚动方向：'top', 'bottom', 'half', 'rightmost', 'leftmost', 'up', 'down', 'left', 'right'
-        :param pixel: 滚动的像素
-        :return: None
-        """
-        if mode == 'top':
-            self.driver.execute_script("window.scrollTo(document.documentElement.scrollLeft,0);")
-
-        elif mode == 'bottom':
-            self.driver.execute_script(
-                "window.scrollTo(document.documentElement.scrollLeft,document.body.scrollHeight);")
-
-        elif mode == 'half':
-            self.driver.execute_script(
-                "window.scrollTo(document.documentElement.scrollLeft,document.body.scrollHeight/2);")
-
-        elif mode == 'rightmost':
-            self.driver.execute_script("window.scrollTo(document.body.scrollWidth,document.documentElement.scrollTop);")
-
-        elif mode == 'leftmost':
-            self.driver.execute_script("window.scrollTo(0,document.documentElement.scrollTop);")
-
-        elif mode == 'up':
-            pixel = pixel if pixel >= 0 else -pixel
-            self.driver.execute_script(f"window.scrollBy(0,{pixel});")
-
-        elif mode == 'down':
-            self.driver.execute_script(f"window.scrollBy(0,{pixel});")
-
-        elif mode == 'left':
-            pixel = pixel if pixel >= 0 else -pixel
-            self.driver.execute_script(f"window.scrollBy({pixel},0);")
-
-        elif mode == 'right':
-            self.driver.execute_script(f"window.scrollBy({pixel},0);")
-
-        else:
-            raise ValueError("mode参数只能是'top', 'bottom', 'half', 'rightmost', "
-                             "'leftmost', 'up', 'down', 'left', 'right'。")
-
     def refresh(self) -> None:
         """刷新当前页面"""
         self.driver.refresh()
@@ -552,6 +498,87 @@ class DriverPage(BasePage):
         return text
 
 
+class ToFrame(object):
+    """用于处理焦点跳转到页面框架的类"""
+
+    def __init__(self, page: DriverPage):
+        self.page = page
+
+    def __call__(self, condition: Union[int, str, tuple, WebElement, DriverElement] = 'main'):
+        """跳转到(i)frame，可传入id、name、序号、元素对象、定位符                  \n
+        :param condition: (i)frame，可传入id、name、序号、元素对象、定位符
+        :return: 当前页面对象
+        """
+        if isinstance(condition, (DriverElement, WebElement)):
+            self.by_ele(condition)
+        elif isinstance(condition, int):
+            self.by_index(condition)
+        elif ':' not in condition and '=' not in condition and not condition.startswith(('#', '.', '@')):
+            self.by_id(condition)
+        else:
+            self.by_loc(condition)
+
+        return self.page
+
+    def main(self) -> DriverPage:
+        """焦点跳转到最高层级框架"""
+        self.page.driver.switch_to.default_content()
+        return self.page
+
+    def parent(self, level: int = 1) -> DriverPage:
+        """焦点跳转到上级框架，可指定上级层数       \n
+        :param level: 上面第几层框架
+        :return: 框架所在页面对象
+        """
+        if level < 1:
+            raise ValueError('level参数须是大于0的整数。')
+        for _ in range(level):
+            self.page.driver.switch_to.parent_frame()
+        return self.page
+
+    def by_id(self, id_: str) -> DriverPage:
+        """焦点跳转到id为该值的(i)frame              \n
+        :param id_: (i)frame的id属性值
+        :return: 框架所在页面对象
+        """
+        self.page.driver.switch_to.frame(id_)
+        return self.page
+
+    def by_name(self, name: str) -> DriverPage:
+        """焦点跳转到name为该值的(i)frame              \n
+        :param name: (i)frame的name属性值
+        :return: 框架所在页面对象
+        """
+        self.page.driver.switch_to.frame(name)
+        return self.page
+
+    def by_index(self, index: int) -> DriverPage:
+        """焦点跳转到页面中第几个(i)frame              \n
+        :param index: 页面中第几个(i)frame
+        :return: 框架所在页面对象
+        """
+        self.page.driver.switch_to.frame(index)
+        return self.page
+
+    def by_loc(self, loc: Union[str, tuple]) -> DriverPage:
+        """焦点跳转到根据定位符获取到的(i)frame                   \n
+        :param loc: 定位符，支持selenium原生和DriverPage定位符
+        :return: 框架所在页面对象
+        """
+        self.page.driver.switch_to.frame(self.page(loc).inner_ele)
+        return self.page
+
+    def by_ele(self, ele: Union[DriverElement, WebElement]) -> DriverPage:
+        """焦点跳转到传入的(i)frame元素对象              \n
+        :param ele: (i)frame元素对象
+        :return: 框架所在页面对象
+        """
+        if isinstance(ele, DriverElement):
+            ele = ele.inner_ele
+        self.page.driver.switch_to.frame(ele)
+        return self.page
+
+
 def _get_handles(handles: list, num_or_handles: Union[int, str, list, tuple]) -> set:
     """返回指定标签页组成的set
     :param handles: handles列表
